# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetUsersVotes(BaseModel):
    get_users_votes: Optional[List[Optional["GetUsersVotesGetUsersVotes"]]] = Field(
        alias="getUsersVotes"
    )


class GetUsersVotesGetUsersVotes(BaseModel):
    id: Optional[str]
    vote_id: Optional[str] = Field(alias="voteId")
    user_cognito_id: Optional[str] = Field(alias="userCognitoId")


GetUsersVotes.update_forward_refs()
GetUsersVotesGetUsersVotes.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitionOrganiserInfo(BaseModel):
    get_competition_organiser_info: Optional[
        "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo"
    ] = Field(alias="getCompetitionOrganiserInfo")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo(BaseModel):
    units: Optional[
        List[Optional["GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits"]]
    ]
    website_url: Optional[str] = Field(alias="websiteUrl")
    results_page_url: Optional[str] = Field(alias="resultsPageUrl")
    live_streaming_url: Optional[str] = Field(alias="liveStreamingUrl")
    contact_persons_general_matters: Optional[
        List[
            Optional[
                "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters"
            ]
        ]
    ] = Field(alias="contactPersonsGeneralMatters")
    contact_persons_general_results: Optional[
        List[
            Optional[
                "GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults"
            ]
        ]
    ] = Field(alias="contactPersonsGeneralResults")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits(BaseModel):
    events: Optional[List[Optional[str]]]
    gender: Optional[str]


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters(
    BaseModel
):
    name: Optional[str]
    email: Optional[str]
    phone_number: Optional[str] = Field(alias="phoneNumber")


class GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults(
    BaseModel
):
    name: Optional[str]
    email: Optional[str]
    phone_number: Optional[str] = Field(alias="phoneNumber")


GetCompetitionOrganiserInfo.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfo.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoUnits.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralMatters.update_forward_refs()
GetCompetitionOrganiserInfoGetCompetitionOrganiserInfoContactPersonsGeneralResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetSingleCompetitorAllTimePersonalTop10(BaseModel):
    get_single_competitor_all_time_personal_top10: Optional[
        "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10"
    ] = Field(alias="getSingleCompetitorAllTimePersonalTop10")


class GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10(
    BaseModel
):
    parameters: Optional[
        "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Parameters"
    ]
    disciplines: Optional[
        List[
            Optional[
                "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Disciplines"
            ]
        ]
    ]
    results: Optional[
        List[
            Optional[
                "GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Results"
            ]
        ]
    ]


class GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Parameters(
    BaseModel
):
    all_time_personal_top10_discipline: Optional[int] = Field(
        alias="allTimePersonalTop10Discipline"
    )


class GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Disciplines(
    BaseModel
):
    id: Optional[int]
    name: Optional[str]


class GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Results(
    BaseModel
):
    discipline: Optional[str]
    date: Optional[str]
    competition: Optional[str]
    country: Optional[str]
    category: Optional[str]
    race: Optional[str]
    place: Optional[str]
    result: Optional[str]
    wind: Optional[str]
    drop: Optional[str]
    with_wind: Optional[bool] = Field(alias="withWind")
    with_drop: Optional[bool] = Field(alias="withDrop")
    score: Optional[int]
    records: Optional[List[Optional[str]]]
    remark: Optional[str]


GetSingleCompetitorAllTimePersonalTop10.update_forward_refs()
GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10.update_forward_refs()
GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Parameters.update_forward_refs()
GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Disciplines.update_forward_refs()
GetSingleCompetitorAllTimePersonalTop10GetSingleCompetitorAllTimePersonalTop10Results.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetChampionshipQualifications(BaseModel):
    get_championship_qualifications: Optional[
        "GetChampionshipQualificationsGetChampionshipQualifications"
    ] = Field(alias="getChampionshipQualifications")


class GetChampionshipQualificationsGetChampionshipQualifications(BaseModel):
    event_id: Optional[int] = Field(alias="eventId")
    group_by_country: Optional[bool] = Field(alias="groupByCountry")
    entry_number: Optional[int] = Field(alias="entryNumber")
    entry_standard: Optional[str] = Field(alias="entryStandard")
    alternative_entry_standards: Optional[
        List[
            Optional[
                "GetChampionshipQualificationsGetChampionshipQualificationsAlternativeEntryStandards"
            ]
        ]
    ] = Field(alias="alternativeEntryStandards")
    max_competitors_by_coutnry: Optional[int] = Field(alias="maxCompetitorsByCoutnry")
    first_qualification_day: Optional[str] = Field(alias="firstQualificationDay")
    last_qualification_day: Optional[str] = Field(alias="lastQualificationDay")
    rank_date: Optional[str] = Field(alias="rankDate")
    first_ranking_day: Optional[str] = Field(alias="firstRankingDay")
    last_ranking_day: Optional[str] = Field(alias="lastRankingDay")
    number_of_competitors_qualified_by_entry_standard: Optional[int] = Field(
        alias="numberOfCompetitorsQualifiedByEntryStandard"
    )
    number_of_competitors_qualified_by_designated_competition: Optional[int] = Field(
        alias="numberOfCompetitorsQualifiedByDesignatedCompetition"
    )
    number_of_competitors_filled_up_by_world_rankings: Optional[int] = Field(
        alias="numberOfCompetitorsFilledUpByWorldRankings"
    )
    number_of_competitors_qualified_by_top_list: Optional[int] = Field(
        alias="numberOfCompetitorsQualifiedByTopList"
    )
    number_of_competitors_qualified_by_universality_places: Optional[int] = Field(
        alias="numberOfCompetitorsQualifiedByUniversalityPlaces"
    )
    qualifications: Optional[
        List[
            Optional[
                "GetChampionshipQualificationsGetChampionshipQualificationsQualifications"
            ]
        ]
    ]
    events: Optional[
        List[
            Optional["GetChampionshipQualificationsGetChampionshipQualificationsEvents"]
        ]
    ]
    countries: Optional[
        List[
            Optional[
                "GetChampionshipQualificationsGetChampionshipQualificationsCountries"
            ]
        ]
    ]
    qualification_types: Optional[
        List[
            Optional[
                "GetChampionshipQualificationsGetChampionshipQualificationsQualificationTypes"
            ]
        ]
    ] = Field(alias="qualificationTypes")
    discipline_name: Optional[str] = Field(alias="disciplineName")


class GetChampionshipQualificationsGetChampionshipQualificationsAlternativeEntryStandards(
    BaseModel
):
    entry_standard: Optional[str] = Field(alias="entryStandard")
    event: Optional[str]


class GetChampionshipQualificationsGetChampionshipQualificationsQualifications(
    BaseModel
):
    qualified_by: Optional[str] = Field(alias="qualifiedBy")
    qualified: Optional[bool]
    qualification_position: Optional[int] = Field(alias="qualificationPosition")
    country_position: Optional[int] = Field(alias="countryPosition")
    name: Optional[str]
    url_slug: Optional[str] = Field(alias="urlSlug")
    iaaf_id: Optional[int] = Field(alias="iaafId")
    birth_date: Optional[str] = Field(alias="birthDate")
    competitor_iaaf_id: Optional[int] = Field(alias="competitorIaafId")
    result: Optional[str]
    wind: Optional[str]
    venue: Optional[str]
    date: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    place: Optional[int]
    score: Optional[int]
    calculation_id: Optional[int] = Field(alias="calculationId")
    label: Optional[str]


class GetChampionshipQualificationsGetChampionshipQualificationsEvents(BaseModel):
    gender_code: Optional[str] = Field(alias="genderCode")
    event_id: Optional[str] = Field(alias="eventId")
    discipline_name: Optional[str] = Field(alias="disciplineName")


class GetChampionshipQualificationsGetChampionshipQualificationsCountries(BaseModel):
    shortname: Optional[str]
    name: Optional[str]


class GetChampionshipQualificationsGetChampionshipQualificationsQualificationTypes(
    BaseModel
):
    id: Optional[str]
    name: Optional[str]


GetChampionshipQualifications.update_forward_refs()
GetChampionshipQualificationsGetChampionshipQualifications.update_forward_refs()
GetChampionshipQualificationsGetChampionshipQualificationsAlternativeEntryStandards.update_forward_refs()
GetChampionshipQualificationsGetChampionshipQualificationsQualifications.update_forward_refs()
GetChampionshipQualificationsGetChampionshipQualificationsEvents.update_forward_refs()
GetChampionshipQualificationsGetChampionshipQualificationsCountries.update_forward_refs()
GetChampionshipQualificationsGetChampionshipQualificationsQualificationTypes.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetVideoPlaylist(BaseModel):
    get_video_playlist: Optional[
        List[Optional["GetVideoPlaylistGetVideoPlaylist"]]
    ] = Field(alias="getVideoPlaylist")


class GetVideoPlaylistGetVideoPlaylist(BaseModel):
    id: Optional[str]
    title: Optional[str]
    slug: Optional[str]


GetVideoPlaylist.update_forward_refs()
GetVideoPlaylistGetVideoPlaylist.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class GetVocabulary(BaseModel):
    get_vocabulary: Optional["GetVocabularyGetVocabulary"] = Field(
        alias="getVocabulary"
    )


class GetVocabularyGetVocabulary(BaseModel):
    vocabulary: Optional[Any]


GetVocabulary.update_forward_refs()
GetVocabularyGetVocabulary.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetTopList(BaseModel):
    get_top_list: Optional["GetTopListGetTopList"] = Field(alias="getTopList")


class GetTopListGetTopList(BaseModel):
    page: Optional[int]
    pages: Optional[int]
    payload: Optional[List[Optional["GetTopListGetTopListPayload"]]]


class GetTopListGetTopListPayload(BaseModel):
    position: Optional[int]
    place: Optional[str]
    achiever_position: Optional[int] = Field(alias="achieverPosition")
    result: Optional[str]
    achiever: Optional[str]
    nationality: Optional[str]
    venue: Optional[str]
    date: Optional[str]
    result_score: Optional[int] = Field(alias="resultScore")


GetTopList.update_forward_refs()
GetTopListGetTopList.update_forward_refs()
GetTopListGetTopListPayload.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAppearance(BaseModel):
    get_appearance: Optional["GetAppearanceGetAppearance"] = Field(
        alias="getAppearance"
    )


class GetAppearanceGetAppearance(BaseModel):
    id: Optional[str]
    name: Optional[str]
    logo_id: Optional[str] = Field(alias="logoId")
    logo: Optional["GetAppearanceGetAppearanceLogo"]
    logo_edited: Optional[str] = Field(alias="logoEdited")
    feature_image_id: Optional[str] = Field(alias="featureImageId")
    feature_image: Optional["GetAppearanceGetAppearanceFeatureImage"] = Field(
        alias="featureImage"
    )
    feature_image_edited: Optional[str] = Field(alias="featureImageEdited")
    theme: Optional[str]
    default_sponsor_ids: Optional[List[Optional[str]]] = Field(
        alias="defaultSponsorIds"
    )
    default_sponsors: Optional[
        List[Optional["GetAppearanceGetAppearanceDefaultSponsors"]]
    ] = Field(alias="defaultSponsors")
    sponsor_ids: Optional[List[Optional[str]]] = Field(alias="sponsorIds")
    sponsors: Optional[List[Optional["GetAppearanceGetAppearanceSponsors"]]]
    event_id: Optional[int] = Field(alias="eventId")
    primary_color: Optional[str] = Field(alias="primaryColor")
    secondary_color: Optional[str] = Field(alias="secondaryColor")
    tertiary_color: Optional[str] = Field(alias="tertiaryColor")
    additional_colours: Optional[List[Optional[str]]] = Field(alias="additionalColours")
    language_codes: Optional[List[Optional[str]]] = Field(alias="languageCodes")


class GetAppearanceGetAppearanceLogo(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetAppearanceGetAppearanceFeatureImage(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetAppearanceGetAppearanceDefaultSponsors(BaseModel):
    id: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    type: Optional[str]
    name: Optional[str]
    url: Optional[str]
    logo_scale: Optional[str] = Field(alias="logoScale")
    light_bg_logo_id: Optional[str] = Field(alias="lightBgLogoId")
    light_bg_logo: Optional[
        "GetAppearanceGetAppearanceDefaultSponsorsLightBgLogo"
    ] = Field(alias="lightBgLogo")
    light_bg_logo_edited: Optional[str] = Field(alias="lightBgLogoEdited")
    dark_bg_logo_id: Optional[str] = Field(alias="darkBgLogoId")
    dark_bg_logo: Optional[
        "GetAppearanceGetAppearanceDefaultSponsorsDarkBgLogo"
    ] = Field(alias="darkBgLogo")
    dark_bg_logo_edited: Optional[str] = Field(alias="darkBgLogoEdited")


class GetAppearanceGetAppearanceDefaultSponsorsLightBgLogo(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetAppearanceGetAppearanceDefaultSponsorsDarkBgLogo(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetAppearanceGetAppearanceSponsors(BaseModel):
    id: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    type: Optional[str]
    name: Optional[str]
    url: Optional[str]
    logo_scale: Optional[str] = Field(alias="logoScale")
    light_bg_logo_id: Optional[str] = Field(alias="lightBgLogoId")
    light_bg_logo: Optional["GetAppearanceGetAppearanceSponsorsLightBgLogo"] = Field(
        alias="lightBgLogo"
    )
    light_bg_logo_edited: Optional[str] = Field(alias="lightBgLogoEdited")
    dark_bg_logo_id: Optional[str] = Field(alias="darkBgLogoId")
    dark_bg_logo: Optional["GetAppearanceGetAppearanceSponsorsDarkBgLogo"] = Field(
        alias="darkBgLogo"
    )
    dark_bg_logo_edited: Optional[str] = Field(alias="darkBgLogoEdited")


class GetAppearanceGetAppearanceSponsorsLightBgLogo(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetAppearanceGetAppearanceSponsorsDarkBgLogo(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


GetAppearance.update_forward_refs()
GetAppearanceGetAppearance.update_forward_refs()
GetAppearanceGetAppearanceLogo.update_forward_refs()
GetAppearanceGetAppearanceFeatureImage.update_forward_refs()
GetAppearanceGetAppearanceDefaultSponsors.update_forward_refs()
GetAppearanceGetAppearanceDefaultSponsorsLightBgLogo.update_forward_refs()
GetAppearanceGetAppearanceDefaultSponsorsDarkBgLogo.update_forward_refs()
GetAppearanceGetAppearanceSponsors.update_forward_refs()
GetAppearanceGetAppearanceSponsorsLightBgLogo.update_forward_refs()
GetAppearanceGetAppearanceSponsorsDarkBgLogo.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWawEventCountryList(BaseModel):
    get_waw_event_country_list: Optional[
        List[Optional["GetWawEventCountryListGetWawEventCountryList"]]
    ] = Field(alias="getWawEventCountryList")


class GetWawEventCountryListGetWawEventCountryList(BaseModel):
    letter: Optional[str]
    countries: Optional[
        List[Optional["GetWawEventCountryListGetWawEventCountryListCountries"]]
    ]


class GetWawEventCountryListGetWawEventCountryListCountries(BaseModel):
    name: Optional[str]
    code: Optional[str]
    slug: Optional[str]


GetWawEventCountryList.update_forward_refs()
GetWawEventCountryListGetWawEventCountryList.update_forward_refs()
GetWawEventCountryListGetWawEventCountryListCountries.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetWawMedalDetails(BaseModel):
    get_waw_medal_details: Optional[
        List[Optional["GetWawMedalDetailsGetWawMedalDetails"]]
    ] = Field(alias="getWawMedalDetails")


class GetWawMedalDetailsGetWawMedalDetails(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    medal_table_id: Optional[int] = Field(alias="medalTableId")
    type_id: Optional[int] = Field(alias="typeId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    result_id: Optional[int] = Field(alias="resultId")
    result_mark: Optional[str] = Field(alias="resultMark")
    event_id: Optional[int] = Field(alias="eventId")
    phase_id: Optional[int] = Field(alias="phaseId")
    medal_date: Optional[Any] = Field(alias="medalDate")
    details_order: Optional[int] = Field(alias="detailsOrder")
    competitor_id: Optional[int] = Field(alias="competitorId")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    competitor: Optional["GetWawMedalDetailsGetWawMedalDetailsCompetitor"]
    discipline: Optional["GetWawMedalDetailsGetWawMedalDetailsDiscipline"]


class GetWawMedalDetailsGetWawMedalDetailsCompetitor(BaseModel):
    id: Optional[int] = Field(alias="_id")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    information: Optional[str]
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date: Optional[Any] = Field(alias="birthDate")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_type_code: Optional[str] = Field(alias="representativeTypeCode")
    representative_id: Optional[int] = Field(alias="representativeId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    name: Optional[str]
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")


class GetWawMedalDetailsGetWawMedalDetailsDiscipline(BaseModel):
    id: Optional[str] = Field(alias="_id")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


GetWawMedalDetails.update_forward_refs()
GetWawMedalDetailsGetWawMedalDetails.update_forward_refs()
GetWawMedalDetailsGetWawMedalDetailsCompetitor.update_forward_refs()
GetWawMedalDetailsGetWawMedalDetailsDiscipline.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetLiveCombinedSummaryDetails(BaseModel):
    get_live_combined_summary_details: Optional[
        List[Optional["GetLiveCombinedSummaryDetailsGetLiveCombinedSummaryDetails"]]
    ] = Field(alias="getLiveCombinedSummaryDetails")


class GetLiveCombinedSummaryDetailsGetLiveCombinedSummaryDetails(BaseModel):
    id: Optional[str]
    phase_id: int = Field(alias="phaseId")
    competition_id: Optional[int] = Field(alias="competitionId")
    overall_rank: Optional[int] = Field(alias="overallRank")
    bib: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_birth_date: Optional[str] = Field(alias="competitorBirthDate")
    result_mark: Optional[str] = Field(alias="resultMark")
    record: Optional[str]
    details_disc_order: Optional[int] = Field(alias="detailsDiscOrder")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_mark: Optional[str] = Field(alias="disciplineMark")
    detail_wind: Optional[str] = Field(alias="detailWind")
    overall_points: Optional[int] = Field(alias="overallPoints")
    overall_order: Optional[int] = Field(alias="overallOrder")
    detail_combined_rank: Optional[str] = Field(alias="detailCombinedRank")
    discipline_rank: Optional[str] = Field(alias="disciplineRank")
    discipline_points: Optional[str] = Field(alias="disciplinePoints")
    update_on: Optional[str] = Field(alias="updateOn")
    combined_type: Optional[str] = Field(alias="combinedType")
    event_store_id: Optional[str] = Field(alias="eventStoreId")


GetLiveCombinedSummaryDetails.update_forward_refs()
GetLiveCombinedSummaryDetailsGetLiveCombinedSummaryDetails.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAssets(BaseModel):
    get_assets: Optional[List[Optional["GetAssetsGetAssets"]]] = Field(
        alias="getAssets"
    )


class GetAssetsGetAssets(BaseModel):
    id: Optional[str]
    slug: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    thumbnail_feature_image_id: Optional[str] = Field(alias="thumbnailFeatureImageId")
    thumbnail_feature_image_edited: Optional[str] = Field(
        alias="thumbnailFeatureImageEdited"
    )
    thumbnail_feature_image: Optional[
        "GetAssetsGetAssetsThumbnailFeatureImage"
    ] = Field(alias="thumbnailFeatureImage")
    gated_content: Optional[bool] = Field(alias="gatedContent")
    download_only: Optional[bool] = Field(alias="downloadOnly")
    tags: Optional[List[Optional[str]]]
    published_by_name: Optional[str] = Field(alias="publishedByName")
    published: Optional[str]
    language: Optional[str]
    title: Optional[str]
    seo_description: Optional[str] = Field(alias="seoDescription")
    video: Optional[str]
    document_id: Optional[str] = Field(alias="documentId")
    document: Optional["GetAssetsGetAssetsDocument"]
    filters: Optional[List[Optional["GetAssetsGetAssetsFilters"]]]
    campaign_id: Optional[str] = Field(alias="campaignId")
    campaign: Optional["GetAssetsGetAssetsCampaign"]
    date: Optional[Any]


class GetAssetsGetAssetsThumbnailFeatureImage(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetAssetsGetAssetsDocument(BaseModel):
    id: Optional[str]
    media_type: Optional[str] = Field(alias="mediaType")
    title: Optional[str]
    copyright: Optional[str]
    file_name: Optional[str] = Field(alias="fileName")
    related_athletes: Optional[List[Optional[int]]] = Field(alias="relatedAthletes")
    related_disciplines: Optional[List[Optional[str]]] = Field(
        alias="relatedDisciplines"
    )
    related_competitions: Optional[List[Optional[str]]] = Field(
        alias="relatedCompetitions"
    )
    related_events: Optional[List[Optional[int]]] = Field(alias="relatedEvents")
    is_deleted: Optional[bool] = Field(alias="isDeleted")
    live_from: Optional[Any] = Field(alias="liveFrom")


class GetAssetsGetAssetsFilters(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    type_id: Optional[str] = Field(alias="typeId")
    type: Optional["GetAssetsGetAssetsFiltersType"]
    published: Optional[Any]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    language: Optional[str]
    title: Optional[str]
    slug: Optional[str]


class GetAssetsGetAssetsFiltersType(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    published: Optional[Any]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    filters: Optional[List[Optional["GetAssetsGetAssetsFiltersTypeFilters"]]]
    language: Optional[str]
    title: Optional[str]
    slug: Optional[str]
    type_id: Optional[str] = Field(alias="typeId")
    site_id: Optional[str] = Field(alias="siteId")


class GetAssetsGetAssetsFiltersTypeFilters(BaseModel):
    id: Optional[str]
    content_id: Optional[str] = Field(alias="contentId")
    type_id: Optional[str] = Field(alias="typeId")
    published: Optional[Any]
    published_by_id: Optional[str] = Field(alias="publishedById")
    published_by_name: Optional[str] = Field(alias="publishedByName")
    language: Optional[str]
    title: Optional[str]
    slug: Optional[str]


class GetAssetsGetAssetsCampaign(BaseModel):
    id: Optional[str]
    name: Optional[str]
    tag: Optional[str]
    type: Optional[str]
    description: Optional[str]
    thank_you_message: Optional[str] = Field(alias="thankYouMessage")
    already_signed_message: Optional[str] = Field(alias="alreadySignedMessage")
    close_date: Optional[Any] = Field(alias="closeDate")
    redirect_url: Optional[str] = Field(alias="redirectUrl")
    tag_user_friendly_name: Optional[str] = Field(alias="tagUserFriendlyName")
    background_image_edited: Optional[str] = Field(alias="backgroundImageEdited")
    header_image_edited: Optional[str] = Field(alias="headerImageEdited")
    visible_on_preference_center: Optional[bool] = Field(
        alias="visibleOnPreferenceCenter"
    )
    short_form: Optional[bool] = Field(alias="shortForm")
    top_level_bucket_id: Optional[str] = Field(alias="topLevelBucketId")


GetAssets.update_forward_refs()
GetAssetsGetAssets.update_forward_refs()
GetAssetsGetAssetsThumbnailFeatureImage.update_forward_refs()
GetAssetsGetAssetsDocument.update_forward_refs()
GetAssetsGetAssetsFilters.update_forward_refs()
GetAssetsGetAssetsFiltersType.update_forward_refs()
GetAssetsGetAssetsFiltersTypeFilters.update_forward_refs()
GetAssetsGetAssetsCampaign.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAllGoldTourEvents(BaseModel):
    get_all_gold_tour_events: Optional[
        "GetAllGoldTourEventsGetAllGoldTourEvents"
    ] = Field(alias="getAllGoldTourEvents")


class GetAllGoldTourEventsGetAllGoldTourEvents(BaseModel):
    events: Optional[List[Optional["GetAllGoldTourEventsGetAllGoldTourEventsEvents"]]]


class GetAllGoldTourEventsGetAllGoldTourEventsEvents(BaseModel):
    nameof_event: Optional[str] = Field(alias="NameofEvent")
    nameof_location: Optional[str] = Field(alias="NameofLocation")
    youtube_video_id: Optional[str] = Field(alias="YoutubeVideoId")
    event_date: Optional[str] = Field(alias="EventDate")


GetAllGoldTourEvents.update_forward_refs()
GetAllGoldTourEventsGetAllGoldTourEvents.update_forward_refs()
GetAllGoldTourEventsGetAllGoldTourEventsEvents.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/schema.graphql

from enum import Enum


class AirQualityDeviceFilter(str, Enum):
    all = "all"
    linked = "linked"
    unlinked = "unlinked"


class CarouselTypeEnum(str, Enum):
    Home = "Home"
    News = "News"
    SingleNews = "SingleNews"
    SingleFeature = "SingleFeature"
    AthleteHero = "AthleteHero"
    BeActiveHero = "BeActiveHero"
    PersonalBest = "PersonalBest"
    Video = "Video"
    UpcomingEvent = "UpcomingEvent"
    EventReport = "EventReport"


class eventPhaseOrderByEnum(str, Enum):
    PhaseDateAndTime = "PhaseDateAndTime"
    PhaseOrder = "PhaseOrder"


class GenderType(str, Enum):
    male = "male"
    female = "female"


class medalsOrderByEnum(str, Enum):
    GOLD = "GOLD"
    TOTAL = "TOTAL"


class MetaDataTypes(str, Enum):
    countryCodes = "countryCodes"
    disciplineCodes = "disciplineCodes"


class OrderByEnum(str, Enum):
    LiveFrom = "LiveFrom"
    EndDate = "EndDate"
    StartDate = "StartDate"


class OrderByLiveBlogPostEnum(str, Enum):
    CreatedDate = "CreatedDate"
    PublishedDate = "PublishedDate"


class OrderByNewArticleEnum(str, Enum):
    PublishedDate = "PublishedDate"
    CreatedDate = "CreatedDate"
    Title = "Title"


class OrderDirectionEnum(str, Enum):
    Ascending = "Ascending"
    Descending = "Descending"


class PlacingTableOrderBy(str, Enum):
    RANK = "RANK"
    TABLE_ORDER = "TABLE_ORDER"


class RelatedCompetitionEnum(str, Enum):
    FeaturedResults = "FeaturedResults"


class TeamStandingOrderBy(str, Enum):
    EVENTTEAMSTANDINGORDER = "EVENTTEAMSTANDINGORDER"



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetCalendarCompetitionResults(BaseModel):
    get_calendar_competition_results: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResults"
    ] = Field(alias="getCalendarCompetitionResults")


class GetCalendarCompetitionResultsGetCalendarCompetitionResults(BaseModel):
    competition: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition"
    ]
    event_titles: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles"
            ]
        ]
    ] = Field(alias="eventTitles")
    options: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions"
    ]
    parameters: Optional[
        "GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters"
    ]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition(BaseModel):
    date_range: Optional[str] = Field(alias="dateRange")
    end_date: Optional[str] = Field(alias="endDate")
    name: Optional[str]
    ranking_category: Optional[str] = Field(alias="rankingCategory")
    start_date: Optional[str] = Field(alias="startDate")
    venue: Optional[str]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles(BaseModel):
    event_title: Optional[str] = Field(alias="eventTitle")
    events: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents"
            ]
        ]
    ]
    ranking_category: Optional[str] = Field(alias="rankingCategory")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents(
    BaseModel
):
    event: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    gender: Optional[str]
    is_relay: Optional[bool] = Field(alias="isRelay")
    per_result_wind: Optional[bool] = Field(alias="perResultWind")
    races: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces"
            ]
        ]
    ]
    summary: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary"
            ]
        ]
    ]
    with_wind: Optional[bool] = Field(alias="withWind")


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces(
    BaseModel
):
    date: Optional[str]
    day: Optional[int]
    race: Optional[str]
    race_id: Optional[int] = Field(alias="raceId")
    race_number: Optional[int] = Field(alias="raceNumber")
    wind: Optional[str]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary(
    BaseModel
):
    mark: Optional[str]
    nationality: Optional[str]
    place_in_race: Optional[str] = Field(alias="placeInRace")
    place_in_round: Optional[str] = Field(alias="placeInRound")
    points: Optional[int]
    race_number: Optional[int] = Field(alias="raceNumber")
    records: Optional[str]
    wind: Optional[str]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions(BaseModel):
    days: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays"
            ]
        ]
    ]
    events: Optional[
        List[
            Optional[
                "GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents"
            ]
        ]
    ]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays(BaseModel):
    date: Optional[str]
    day: Optional[int]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents(
    BaseModel
):
    gender: Optional[str]
    id: Optional[int]
    name: Optional[str]
    combined: Optional[bool]


class GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters(BaseModel):
    competition_id: Optional[int] = Field(alias="competitionId")
    day: Optional[int]
    event_id: Optional[int] = Field(alias="eventId")


GetCalendarCompetitionResults.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResults.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsCompetition.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitles.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEvents.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsRaces.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsEventTitlesEventsSummary.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptions.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsDays.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsOptionsEvents.update_forward_refs()
GetCalendarCompetitionResultsGetCalendarCompetitionResultsParameters.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class SearchAthletes(BaseModel):
    search_athletes: Optional[List[Optional["SearchAthletesSearchAthletes"]]] = Field(
        alias="searchAthletes"
    )


class SearchAthletesSearchAthletes(BaseModel):
    id: Optional[int]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    friendly_name: Optional[str] = Field(alias="friendlyName")
    full_name: Optional[str] = Field(alias="fullName")
    friendly_name_letter: Optional[str] = Field(alias="friendlyNameLetter")
    friendly_name_first3_letter: Optional[str] = Field(alias="friendlyNameFirst3Letter")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    birth_date: Optional[Any] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_place_country_url_slug: Optional[str] = Field(
        alias="birthPlaceCountryUrlSlug"
    )
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    primary_media_id: Optional[str] = Field(alias="primaryMediaId")
    primary_media: Optional[
        List[Optional["SearchAthletesSearchAthletesPrimaryMedia"]]
    ] = Field(alias="primaryMedia")
    url_slug: Optional[str] = Field(alias="urlSlug")
    representative_id: Optional[int] = Field(alias="representativeId")
    biography: Optional[str]
    twitter_link: Optional[str] = Field(alias="twitterLink")
    instagram_link: Optional[str] = Field(alias="instagramLink")
    facebook_link: Optional[str] = Field(alias="facebookLink")
    transfers_of_allegiance: Optional[List[Optional[str]]] = Field(
        alias="transfersOfAllegiance"
    )
    aa_id: Optional[int] = Field(alias="aaId")
    country_full_name: Optional[str] = Field(alias="countryFullName")
    family_name: Optional[str] = Field(alias="familyName")
    given_name: Optional[str] = Field(alias="givenName")
    birth_date_str: Optional[str] = Field(alias="birthDateStr")
    facebook_username: Optional[str] = Field(alias="facebookUsername")
    twitter_username: Optional[str] = Field(alias="twitterUsername")
    instagram_username: Optional[str] = Field(alias="instagramUsername")
    disciplines: Optional[List[Optional["SearchAthletesSearchAthletesDisciplines"]]]
    competition_entries: Optional[
        List[Optional["SearchAthletesSearchAthletesCompetitionEntries"]]
    ] = Field(alias="competitionEntries")


class SearchAthletesSearchAthletesPrimaryMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


class SearchAthletesSearchAthletesDisciplines(BaseModel):
    id: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


class SearchAthletesSearchAthletesCompetitionEntries(BaseModel):
    id: Optional[int]
    event_id: Optional[int] = Field(alias="eventId")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    sex_code: Optional[str] = Field(alias="sexCode")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    competitor_id: Optional[int] = Field(alias="competitorId")
    discipline: Optional["SearchAthletesSearchAthletesCompetitionEntriesDiscipline"]


class SearchAthletesSearchAthletesCompetitionEntriesDiscipline(BaseModel):
    id: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


SearchAthletes.update_forward_refs()
SearchAthletesSearchAthletes.update_forward_refs()
SearchAthletesSearchAthletesPrimaryMedia.update_forward_refs()
SearchAthletesSearchAthletesDisciplines.update_forward_refs()
SearchAthletesSearchAthletesCompetitionEntries.update_forward_refs()
SearchAthletesSearchAthletesCompetitionEntriesDiscipline.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetLiveResult(BaseModel):
    get_live_result: Optional[List[Optional["GetLiveResultGetLiveResult"]]] = Field(
        alias="getLiveResult"
    )


class GetLiveResultGetLiveResult(BaseModel):
    type: Optional[str]
    id: str
    phase_id: int = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type: Optional[str] = Field(alias="unitType")
    intermediate_type: Optional[str] = Field(alias="intermediateType")
    intermediate_id: Optional[int] = Field(alias="intermediateId")
    split_name: Optional[str] = Field(alias="splitName")
    intermediate_id_type: Optional[str] = Field(alias="intermediateIdType")
    intermediate_result_order: Optional[int] = Field(alias="intermediateResultOrder")
    intermediate_order: Optional[int] = Field(alias="intermediateOrder")
    standing_points: Optional[str] = Field(alias="standingPoints")
    gap: Optional[str]
    result_id: Optional[int] = Field(alias="resultId")
    no_start: Optional[bool] = Field(alias="noStart")
    lane: Optional[str]
    season_best_mark: Optional[str] = Field(alias="seasonBestMark")
    personal_best_mark: Optional[str] = Field(alias="personalBestMark")
    phase_summary_order: Optional[int] = Field(alias="phaseSummaryOrder")
    result_ranks: Optional[int] = Field(alias="resultRanks")
    summary_yank: Optional[int] = Field(alias="summaryYank")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_team_name: Optional[str] = Field(alias="competitorTeamName")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_sex: Optional[str] = Field(alias="competitorSex")
    competitor_type: Optional[str] = Field(alias="competitorType")
    bib: Optional[str]
    rank: Optional[str]
    mark: Optional[str]
    combined_points: Optional[str] = Field(alias="combinedPoints")
    reaction_time: Optional[str] = Field(alias="reactionTime")
    record: Optional[str]
    result_order: Optional[int] = Field(alias="resultOrder")
    start_order: Optional[int] = Field(alias="startOrder")
    qualified: Optional[str]
    next: Optional[bool]
    last: Optional[bool]
    updated_on: Optional[str] = Field(alias="updatedOn")
    wind: Optional[str]
    team_name: Optional[str] = Field(alias="teamName")
    team_members: Optional[
        List[Optional["GetLiveResultGetLiveResultTeamMembers"]]
    ] = Field(alias="teamMembers")
    event_store_id: Optional[str] = Field(alias="eventStoreId")
    competition_id: Optional[int] = Field(alias="competitionId")
    result_milliseconds: Optional[str] = Field(alias="resultMilliseconds")
    world_ranking: Optional[str] = Field(alias="worldRanking")


class GetLiveResultGetLiveResultTeamMembers(BaseModel):
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_name: Optional[str] = Field(alias="unitName")
    live_result_id: Optional[int] = Field(alias="liveResultId")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")


GetLiveResult.update_forward_refs()
GetLiveResultGetLiveResult.update_forward_refs()
GetLiveResultGetLiveResultTeamMembers.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetEventPhaseByDiscipline(BaseModel):
    get_event_phase_by_discipline: Optional[
        "GetEventPhaseByDisciplineGetEventPhaseByDiscipline"
    ] = Field(alias="getEventPhaseByDiscipline")


class GetEventPhaseByDisciplineGetEventPhaseByDiscipline(BaseModel):
    id: Optional[int]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    phase_code: Optional[str] = Field(alias="phaseCode")
    phase_name: Optional[str] = Field(alias="phaseName")
    event_i_d: Optional[int] = Field(alias="eventID")
    phase_date_and_time: Optional[Any] = Field(alias="phaseDateAndTime")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    discipline: Optional["GetEventPhaseByDisciplineGetEventPhaseByDisciplineDiscipline"]
    is_startlist_published: Optional[bool] = Field(alias="isStartlistPublished")
    is_result_published: Optional[bool] = Field(alias="isResultPublished")
    is_phase_summary_published: Optional[bool] = Field(alias="isPhaseSummaryPublished")
    is_team_standing_published: Optional[bool] = Field(alias="isTeamStandingPublished")
    combined_discipline_order: Optional[int] = Field(alias="combinedDisciplineOrder")
    phase_order: Optional[int] = Field(alias="phaseOrder")
    phase_session_name: Optional[str] = Field(alias="phaseSessionName")
    phase_session_order: Optional[int] = Field(alias="phaseSessionOrder")
    status: Optional[int]
    has_time: Optional[bool] = Field(alias="hasTime")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    primary_phase_order: Optional[int] = Field(alias="primaryPhaseOrder")
    is_points_published: Optional[bool] = Field(alias="isPointsPublished")
    phase_name_url_slug: Optional[str] = Field(alias="phaseNameUrlSlug")
    sex_name_url_slug: Optional[str] = Field(alias="sexNameUrlSlug")
    is_track: Optional[bool] = Field(alias="isTrack")
    units: Optional[
        List[Optional["GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnits"]]
    ]
    summary: Optional[
        List[Optional["GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummary"]]
    ]
    documents: Optional[
        List[Optional["GetEventPhaseByDisciplineGetEventPhaseByDisciplineDocuments"]]
    ]


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineDiscipline(BaseModel):
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    id: Optional[str] = Field(alias="_id")
    name: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    type_name: Optional[str] = Field(alias="typeName")
    type_order: Optional[int] = Field(alias="typeOrder")
    order: Optional[int]
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnits(BaseModel):
    unit_id: Optional[int] = Field(alias="unitId")
    unit_date_time: Optional[Any] = Field(alias="unitDateTime")
    has_standing_points: Optional[bool] = Field(alias="hasStandingPoints")
    unit_rule_detail: Optional[str] = Field(alias="unitRuleDetail")
    unit_type_code: Optional[str] = Field(alias="unitTypeCode")
    unit_type_name: Optional[str] = Field(alias="unitTypeName")
    unit_code: Optional[str] = Field(alias="unitCode")
    unit_order: Optional[int] = Field(alias="unitOrder")
    results: Optional[
        List[Optional["GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResults"]]
    ]
    startlist: Optional[
        List[
            Optional["GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlist"]
        ]
    ]
    series: Optional[
        List[Optional["GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeries"]]
    ]
    splits: Optional[
        List[
            Optional[
                List[
                    Optional[
                        "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSplits"
                    ]
                ]
            ]
        ]
    ]
    team_standings: Optional[
        List[
            Optional[
                "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandings"
            ]
        ]
    ] = Field(alias="teamStandings")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResults(BaseModel):
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    competitor_type_code: Optional[str] = Field(alias="competitorTypeCode")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    standing_points: Optional[str] = Field(alias="standingPoints")
    combined_points: Optional[str] = Field(alias="combinedPoints")
    competitor_id: Optional[int] = Field(alias="competitorId")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_wind: Optional[str] = Field(alias="resultWind")
    result_rank: Optional[int] = Field(alias="resultRank")
    result_order: Optional[int] = Field(alias="resultOrder")
    reaction_time: Optional[str] = Field(alias="reactionTime")
    record: Optional[str]
    bib: Optional[str]
    qualified: Optional[str]
    team_members: Optional[
        List[
            Optional[
                "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResultsTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResultsTeamMembers(
    BaseModel
):
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_rank: Optional[str] = Field(alias="resultRank")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    country_name: Optional[str] = Field(alias="countryName")
    competitor_order: Optional[int] = Field(alias="competitorOrder")
    standing_detail_scoring: Optional[bool] = Field(alias="standingDetailScoring")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlist(BaseModel):
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    competitor_type_code: Optional[str] = Field(alias="competitorTypeCode")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    competitor_id: Optional[int] = Field(alias="competitorId")
    personal_best_mark: Optional[str] = Field(alias="personalBestMark")
    season_best_mark: Optional[str] = Field(alias="seasonBestMark")
    world_ranking: Optional[str] = Field(alias="worldRanking")
    bib: Optional[str]
    startlist_order: Optional[int] = Field(alias="startlistOrder")
    record: Optional[str]
    start: Optional[int]
    team_members: Optional[
        List[
            Optional[
                "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlistTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlistTeamMembers(
    BaseModel
):
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_rank: Optional[str] = Field(alias="resultRank")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    country_name: Optional[str] = Field(alias="countryName")
    competitor_order: Optional[int] = Field(alias="competitorOrder")
    standing_detail_scoring: Optional[bool] = Field(alias="standingDetailScoring")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeries(BaseModel):
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    competitor_type_code: Optional[str] = Field(alias="competitorTypeCode")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_id: Optional[int] = Field(alias="competitorId")
    bib: Optional[str]
    startlist_order: Optional[int] = Field(alias="startlistOrder")
    qualified: Optional[str]
    result_wind: Optional[str] = Field(alias="resultWind")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_order: Optional[str] = Field(alias="resultOrder")
    record: Optional[str]
    attempts: Optional[
        List[
            Optional[
                "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeriesAttempts"
            ]
        ]
    ]


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeriesAttempts(BaseModel):
    intermediate_mark: Optional[str] = Field(alias="intermediateMark")
    intermediate_wind: Optional[str] = Field(alias="intermediateWind")
    competition_intermediate_name: Optional[str] = Field(
        alias="competitionIntermediateName"
    )
    intermediate_gap: Optional[str] = Field(alias="intermediateGap")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSplits(BaseModel):
    competition_intermediate_result_order: Optional[int] = Field(
        alias="competitionIntermediateResultOrder"
    )
    competition_intermediate_name: Optional[str] = Field(
        alias="competitionIntermediateName"
    )
    intermediate_mark: Optional[str] = Field(alias="intermediateMark")
    intermediate_gap: Optional[str] = Field(alias="intermediateGap")
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandings(BaseModel):
    id: Optional[int] = Field(alias="_id")
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    rank: Optional[int]
    team_id: Optional[int] = Field(alias="teamId")
    team_name: Optional[str] = Field(alias="teamName")
    team_country_code: Optional[str] = Field(alias="teamCountryCode")
    standing_mark: Optional[str] = Field(alias="standingMark")
    competitor_id: Optional[str] = Field(alias="competitorId")
    team_standing_order: Optional[int] = Field(alias="teamStandingOrder")
    team_event_points: Optional[int] = Field(alias="teamEventPoints")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    team_members: Optional[
        List[
            Optional[
                "GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandingsTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandingsTeamMembers(
    BaseModel
):
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_rank: Optional[str] = Field(alias="resultRank")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    country_name: Optional[str] = Field(alias="countryName")
    competitor_order: Optional[int] = Field(alias="competitorOrder")
    standing_detail_scoring: Optional[bool] = Field(alias="standingDetailScoring")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummary(BaseModel):
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    competitor_type_code: Optional[str] = Field(alias="competitorTypeCode")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    phase_summary_order: Optional[str] = Field(alias="phaseSummaryOrder")
    combined_points: Optional[str] = Field(alias="combinedPoints")
    competitor_id: Optional[int] = Field(alias="competitorId")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_wind: Optional[str] = Field(alias="resultWind")
    result_rank: Optional[int] = Field(alias="resultRank")
    result_order: Optional[int] = Field(alias="resultOrder")
    unit_code: Optional[int] = Field(alias="unitCode")
    unit_name: Optional[str] = Field(alias="unitName")
    reaction_time: Optional[str] = Field(alias="reactionTime")
    record: Optional[str]
    bib: Optional[str]
    qualified: Optional[str]
    summary_rank: Optional[int] = Field(alias="summaryRank")
    team_members: Optional[
        List[
            Optional[
                "GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummaryTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummaryTeamMembers(BaseModel):
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    competitor_name: Optional[str] = Field(alias="competitorName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    result_mark: Optional[str] = Field(alias="resultMark")
    result_rank: Optional[str] = Field(alias="resultRank")
    result_country_name: Optional[str] = Field(alias="resultCountryName")
    result_country_code: Optional[str] = Field(alias="resultCountryCode")
    country_name: Optional[str] = Field(alias="countryName")
    competitor_order: Optional[int] = Field(alias="competitorOrder")
    standing_detail_scoring: Optional[bool] = Field(alias="standingDetailScoring")


class GetEventPhaseByDisciplineGetEventPhaseByDisciplineDocuments(BaseModel):
    type: Optional[int]
    type_name: Optional[str] = Field(alias="typeName")
    file_name: Optional[str] = Field(alias="fileName")
    file_path: Optional[str] = Field(alias="filePath")
    unit_id: Optional[int] = Field(alias="unitId")


GetEventPhaseByDiscipline.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDiscipline.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineDiscipline.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnits.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResults.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsResultsTeamMembers.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlist.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsStartlistTeamMembers.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeries.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSeriesAttempts.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsSplits.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandings.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineUnitsTeamStandingsTeamMembers.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummary.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineSummaryTeamMembers.update_forward_refs()
GetEventPhaseByDisciplineGetEventPhaseByDisciplineDocuments.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetOnThisDay(BaseModel):
    get_on_this_day: Optional["GetOnThisDayGetOnThisDay"] = Field(alias="getOnThisDay")


class GetOnThisDayGetOnThisDay(BaseModel):
    module_title: Optional[str] = Field(alias="moduleTitle")
    module_subtitle: Optional[str] = Field(alias="moduleSubtitle")
    results: Optional[List[Optional["GetOnThisDayGetOnThisDayResults"]]]


class GetOnThisDayGetOnThisDayResults(BaseModel):
    id: Optional[int]
    category: Optional[str]
    title: Optional[str]
    body: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")


GetOnThisDay.update_forward_refs()
GetOnThisDayGetOnThisDay.update_forward_refs()
GetOnThisDayGetOnThisDayResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/schema.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class AAapiQuery(BaseModel):
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    gender: Optional[str]
    environment: Optional[str]
    age_category: Optional[str] = Field(alias="ageCategory")
    wind_reading: Optional[str] = Field(alias="windReading")
    category_id: Optional[int] = Field(alias="categoryId")
    competition_id: Optional[int] = Field(alias="competitionId")
    event_group: Optional[str] = Field(alias="eventGroup")
    best_results_only: Optional[bool] = Field(alias="bestResultsOnly")
    region: Optional[str]
    region_type: Optional[str] = Field(alias="regionType")
    limit: Optional[int]
    season: Optional[int]
    page: Optional[int]
    max_year_available: Optional[int] = Field(alias="maxYearAvailable")


class ChunkType(BaseModel):
    size: Optional[int]
    chunk_order: Optional[int] = Field(alias="chunkOrder")
    chunk_id: Optional[str] = Field(alias="chunkId")


class ClientMetadataInput(BaseModel):
    key: Optional[str]
    value: Optional[str]


class CompetitorInput(BaseModel):
    competitor_id: Optional[int] = Field(alias="competitorId")
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    birth_date: Optional[str] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    team_name: Optional[str] = Field(alias="teamName")
    country_name: Optional[str] = Field(alias="countryName")
    country_code: Optional[str] = Field(alias="countryCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    full_bio: Optional[str] = Field(alias="fullBio")
    butlers_bio: Optional[str] = Field(alias="butlersBio")


class CompetitorQueryInput(BaseModel):
    competitor_id: int = Field(alias="competitorId")


class EventInput(BaseModel):
    id: str
    timezone: Optional[str]
    updated_on: Optional[Any] = Field(alias="updatedOn")
    hash: Optional[str]
    name: Optional[str]
    start_date: Optional[Any] = Field(alias="startDate")
    end_date: Optional[Any] = Field(alias="endDate")
    venue: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    area_code: Optional[str] = Field(alias="areaCode")
    area_name: Optional[str] = Field(alias="areaName")
    age_code: Optional[str] = Field(alias="ageCode")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")
    category_code: Optional[str] = Field(alias="categoryCode")
    category_name: Optional[str] = Field(alias="categoryName")
    category_order: Optional[int] = Field(alias="categoryOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    sub_category_name: Optional[str] = Field(alias="subCategoryName")
    sub_category_order: Optional[int] = Field(alias="subCategoryOrder")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    class_code: Optional[str] = Field(alias="classCode")
    class_name: Optional[str] = Field(alias="className")
    class_order: Optional[int] = Field(alias="classOrder")
    is_published: Optional[bool] = Field(alias="isPublished")
    has_comp_doc_results: Optional[bool] = Field(alias="hasCompDocResults")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    start_date_year: Optional[int] = Field(alias="startDateYear")
    area_name_url_slug: Optional[str] = Field(alias="areaNameUrlSlug")
    category_name_url_slug: Optional[str] = Field(alias="categoryNameUrlSlug")
    sub_category_name_url_slug: Optional[str] = Field(alias="subCategoryNameUrlSlug")
    discipline_codes: Optional[List[Optional[str]]] = Field(alias="disciplineCodes")


class FlashInterviewInput(BaseModel):
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    phase_date: Optional[Any] = Field(alias="phaseDate")
    phase_name: Optional[str] = Field(alias="phaseName")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_code: Optional[int] = Field(alias="unitCode")
    unit_type_name: Optional[str] = Field(alias="unitTypeName")
    unit_name: Optional[str] = Field(alias="unitName")
    title: Optional[str]
    body: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_team_name: Optional[str] = Field(alias="competitorTeamName")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_sex: Optional[str] = Field(alias="competitorSex")
    competitor_type: Optional[str] = Field(alias="competitorType")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    event_id: Optional[int] = Field(alias="eventId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    discipline_sex_name: Optional[str] = Field(alias="disciplineSexName")
    flash_interview_order: Optional[int] = Field(alias="flashInterviewOrder")
    flash_interview_date: Optional[Any] = Field(alias="flashInterviewDate")
    flash_interview_has_time: Optional[bool] = Field(alias="flashInterviewHasTime")
    event_store_id: Optional[str] = Field(alias="eventStoreId")


class LiveCombinedSummaryDetailInput(BaseModel):
    id: Optional[str]
    competition_id: Optional[int] = Field(alias="competitionId")
    phase_id: int = Field(alias="phaseId")
    overall_rank: Optional[int] = Field(alias="overallRank")
    bib: Optional[str]
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_birth_date: Optional[str] = Field(alias="competitorBirthDate")
    result_mark: Optional[str] = Field(alias="resultMark")
    record: Optional[str]
    details_disc_order: Optional[int] = Field(alias="detailsDiscOrder")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_mark: Optional[str] = Field(alias="disciplineMark")
    detail_wind: Optional[str] = Field(alias="detailWind")
    overall_points: Optional[int] = Field(alias="overallPoints")
    overall_order: Optional[int] = Field(alias="overallOrder")
    detail_combined_rank: Optional[str] = Field(alias="detailCombinedRank")
    discipline_rank: Optional[str] = Field(alias="disciplineRank")
    discipline_points: Optional[str] = Field(alias="disciplinePoints")
    update_on: Optional[str] = Field(alias="updateOn")
    combined_type: Optional[str] = Field(alias="combinedType")


class LivePhaseSummaryInput(BaseModel):
    id: str
    phase_summary_id: Optional[int] = Field(alias="phaseSummaryId")
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type: Optional[str] = Field(alias="unitType")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_team_name: Optional[str] = Field(alias="competitorTeamName")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_sex: Optional[str] = Field(alias="competitorSex")
    competitor_type: Optional[str] = Field(alias="competitorType")
    bib: Optional[str]
    rank: Optional[str]
    mark: Optional[str]
    wind: Optional[str]
    result_wind: Optional[str] = Field(alias="resultWind")
    record: Optional[str]
    qualified: Optional[str]
    combined_points: Optional[str] = Field(alias="combinedPoints")
    updated_on: Optional[str] = Field(alias="updatedOn")
    result_rank: Optional[str] = Field(alias="resultRank")
    phase_summary_order: Optional[int] = Field(alias="phaseSummaryOrder")
    provisional_qualifier: Optional[bool] = Field(alias="provisionalQualifier")
    competition_id: Optional[int] = Field(alias="competitionId")
    reaction_time: Optional[str] = Field(alias="reactionTime")
    phase_summary_milliseconds: Optional[str] = Field(alias="phaseSummaryMilliseconds")


class LivePhaseSummaryQuery(BaseModel):
    phase_id: Optional[int] = Field(alias="phaseId")


class LiveResultInput(BaseModel):
    type: Optional[str]
    id: str
    phase_id: int = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type: Optional[str] = Field(alias="unitType")
    intermediate_type: Optional[str] = Field(alias="intermediateType")
    intermediate_id: Optional[int] = Field(alias="intermediateId")
    split_name: Optional[str] = Field(alias="splitName")
    intermediate_id_type: Optional[str] = Field(alias="intermediateIdType")
    intermediate_result_order: Optional[int] = Field(alias="intermediateResultOrder")
    intermediate_order: Optional[int] = Field(alias="intermediateOrder")
    standing_points: Optional[str] = Field(alias="standingPoints")
    gap: Optional[str]
    result_id: Optional[int] = Field(alias="resultId")
    no_start: Optional[bool] = Field(alias="noStart")
    lane: Optional[str]
    season_best_mark: Optional[str] = Field(alias="seasonBestMark")
    personal_best_mark: Optional[str] = Field(alias="personalBestMark")
    phase_summary_order: Optional[int] = Field(alias="phaseSummaryOrder")
    result_ranks: Optional[int] = Field(alias="resultRanks")
    summary_yank: Optional[int] = Field(alias="summaryYank")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_team_name: Optional[str] = Field(alias="competitorTeamName")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")
    competitor_sex: Optional[str] = Field(alias="competitorSex")
    competitor_type: Optional[str] = Field(alias="competitorType")
    bib: Optional[str]
    rank: Optional[str]
    mark: Optional[str]
    combined_points: Optional[str] = Field(alias="combinedPoints")
    reaction_time: Optional[str] = Field(alias="reactionTime")
    record: Optional[str]
    result_order: Optional[int] = Field(alias="resultOrder")
    start_order: Optional[int] = Field(alias="startOrder")
    qualified: Optional[str]
    next: Optional[bool]
    last: Optional[bool]
    updated_on: Optional[str] = Field(alias="updatedOn")
    wind: Optional[str]
    team_name: Optional[str] = Field(alias="teamName")
    team_members: Optional[List[Optional["LiveResultTeamMemberInput"]]] = Field(
        alias="teamMembers"
    )
    competition_id: Optional[int] = Field(alias="competitionId")
    result_milliseconds: Optional[str] = Field(alias="resultMilliseconds")
    world_ranking: Optional[str] = Field(alias="worldRanking")


class LiveResultTeamMemberInput(BaseModel):
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    unit_name: Optional[str] = Field(alias="unitName")
    live_result_id: Optional[int] = Field(alias="liveResultId")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_forename: Optional[str] = Field(alias="competitorForename")
    competitor_surname: Optional[str] = Field(alias="competitorSurname")
    competitor_country_name: Optional[str] = Field(alias="competitorCountryName")
    competitor_country_code: Optional[str] = Field(alias="competitorCountryCode")


class MedalDetailInput(BaseModel):
    id: Optional[int]
    medal_table_id: Optional[int] = Field(alias="medalTableId")
    type_id: Optional[int] = Field(alias="typeId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    sex_code: Optional[str] = Field(alias="sexCode")
    result_id: Optional[int] = Field(alias="resultId")
    result_mark: Optional[str] = Field(alias="resultMark")
    medal_date: Optional[str] = Field(alias="medalDate")
    details_order: Optional[int] = Field(alias="detailsOrder")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    event_id: Optional[int] = Field(alias="eventId")
    phase_id: Optional[int] = Field(alias="phaseId")
    updated_on: Optional[str] = Field(alias="updatedOn")


class MedalInput(BaseModel):
    id: int
    event_id: int = Field(alias="eventId")
    country_code: Optional[str] = Field(alias="countryCode")
    country_name: Optional[str] = Field(alias="countryName")
    event_medal_table_order: Optional[int] = Field(alias="eventMedalTableOrder")
    event_sub_category_code: Optional[str] = Field(alias="eventSubCategoryCode")
    medal_rank: Optional[int] = Field(alias="medalRank")
    bronze: Optional[int]
    silver: Optional[int]
    gold: Optional[int]
    total: Optional[int]
    updated_on: Optional[str] = Field(alias="updatedOn")


class MedalMutationInput(BaseModel):
    event_id: int = Field(alias="eventId")
    payload: List["MedalInput"]


class PhaseInput(BaseModel):
    id: Optional[int]
    phase_code: Optional[str] = Field(alias="phaseCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    discipline_order: Optional[int] = Field(alias="disciplineOrder")
    type_name: Optional[str] = Field(alias="typeName")
    type_code: Optional[str] = Field(alias="typeCode")
    type_order: Optional[int] = Field(alias="typeOrder")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_field: Optional[bool] = Field(alias="isField")
    is_track: Optional[bool] = Field(alias="isTrack")
    is_in_lane: Optional[bool] = Field(alias="isInLane")
    has_reaction_times: Optional[bool] = Field(alias="hasReactionTimes")
    has_wind_measurement: Optional[bool] = Field(alias="hasWindMeasurement")
    inout_code: Optional[bool] = Field(alias="inoutCode")
    has_team_standing: Optional[bool] = Field(alias="hasTeamStanding")
    disc_code_group: Optional[str] = Field(alias="discCodeGroup")
    phase_name: Optional[str] = Field(alias="phaseName")
    event_id: Optional[int] = Field(alias="eventId")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    phase_date_and_time: Optional[str] = Field(alias="phaseDateAndTime")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    is_startlist_published: Optional[bool] = Field(alias="isStartlistPublished")
    is_result_published: Optional[bool] = Field(alias="isResultPublished")
    is_phase_summary_published: Optional[bool] = Field(alias="isPhaseSummaryPublished")
    is_team_standing_published: Optional[bool] = Field(alias="isTeamStandingPublished")
    combined_discipline_order: Optional[str] = Field(alias="combinedDisciplineOrder")
    phase_order: Optional[int] = Field(alias="phaseOrder")
    phase_session_order: Optional[int] = Field(alias="phaseSessionOrder")
    phase_session_name: Optional[str] = Field(alias="phaseSessionName")
    primary_phase_order: Optional[int] = Field(alias="primaryPhaseOrder")
    status: Optional[int]
    has_time: Optional[int] = Field(alias="hasTime")
    updated_on: Optional[str] = Field(alias="updatedOn")
    units: List["UnitInput"]


class PhaseQueryInput(BaseModel):
    competition_id: int = Field(alias="competitionId")
    sex_code: Optional[str] = Field(alias="sexCode")
    discipline_code: Optional[str] = Field(alias="disciplineCode")


class PlacingTableDetailInput(BaseModel):
    id: int
    placing_table_id: int = Field(alias="placingTableId")
    competitor_id: Optional[int] = Field(alias="competitorId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    sex_code: Optional[str] = Field(alias="sexCode")
    placing_date: Optional[Any] = Field(alias="placingDate")
    details_order: Optional[int] = Field(alias="detailsOrder")
    event_id: Optional[int] = Field(alias="eventId")
    type_id: Optional[int] = Field(alias="typeId")
    type_name: Optional[str] = Field(alias="typeName")
    type_abbreviation: Optional[str] = Field(alias="typeAbbreviation")
    result_mark: Optional[str] = Field(alias="resultMark")
    placing_points: Optional[str] = Field(alias="placingPoints")
    result_id: Optional[int] = Field(alias="resultId")
    phase_id: Optional[int] = Field(alias="phaseId")
    country_code: Optional[str] = Field(alias="countryCode")
    updated_on: Optional[Any] = Field(alias="updatedOn")


class PlacingTableInput(BaseModel):
    id: int
    event_id: int = Field(alias="eventId")
    rank: Optional[int]
    country_name: Optional[str] = Field(alias="countryName")
    country_code: Optional[str] = Field(alias="countryCode")
    gold: Optional[int]
    silver: Optional[int]
    bronze: Optional[int]
    forth: Optional[int]
    fifth: Optional[int]
    sixth: Optional[int]
    seventh: Optional[int]
    eighth: Optional[int]
    points: Optional[int]
    table_order: Optional[int] = Field(alias="tableOrder")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    updated_on: Optional[Any] = Field(alias="updatedOn")


class PreviousMedalQuery(BaseModel):
    event_id: Optional[int] = Field(alias="eventId")
    event_id__w_a: Optional[int] = Field(alias="eventId_WA")
    event_end_date: Optional[str] = Field(alias="eventEndDate")
    sub_category_code: Optional[str] = Field(alias="subCategoryCode")
    gender: Optional[str]
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    indoor_out_door: Optional[str] = Field(alias="indoorOutDoor")


class TeamQuery(BaseModel):
    team_id: Optional[int] = Field(alias="teamId")
    team_sex: Optional[str] = Field(alias="teamSex")
    indoor_outdoor: Optional[str] = Field(alias="indoorOutdoor")


class TeamScoringInput(BaseModel):
    id: str
    team_id: Optional[int] = Field(alias="teamId")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    scoring_team_id: Optional[int] = Field(alias="scoringTeamId")
    result_id: Optional[int] = Field(alias="resultId")
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    team_name: Optional[str] = Field(alias="teamName")
    team_country_code: Optional[str] = Field(alias="teamCountryCode")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    scoring_team_order: Optional[int] = Field(alias="scoringTeamOrder")
    scoring_team_detail_order: Optional[int] = Field(alias="scoringTeamDetailOrder")
    bib: Optional[str]
    event_store_id: Optional[str] = Field(alias="eventStoreId")
    chunk_order: Optional[int] = Field(alias="chunkOrder")
    chunk_id: Optional[str] = Field(alias="chunkId")


class TeamStandingsInput(BaseModel):
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_id: Optional[int] = Field(alias="unitId")
    competition_intermediate_id: Optional[int] = Field(
        alias="competitionIntermediateId"
    )
    competition_intermediate_name: Optional[str] = Field(
        alias="competitionIntermediateName"
    )
    rank: Optional[int]
    team_id: Optional[int] = Field(alias="teamId")
    team_id__w_a: Optional[int] = Field(alias="teamId_WA")
    team_name: Optional[str] = Field(alias="teamName")
    team_country_code: Optional[str] = Field(alias="teamCountryCode")
    standing_mark: Optional[str] = Field(alias="standingMark")
    live_current: Optional[bool] = Field(alias="liveCurrent")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    team_standing_id: Optional[int] = Field(alias="teamStandingId")
    competition_intermediate_order: Optional[int] = Field(
        alias="competitionIntermediateOrder"
    )
    detail_rank: Optional[int] = Field(alias="detailRank")
    standing_detail_bib: Optional[str] = Field(alias="standingDetailBib")
    competitor_id: Optional[int] = Field(alias="competitorId")
    competitor_id__w_a: Optional[int] = Field(alias="competitorId_WA")
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId")
    standing_detail_score: Optional[str] = Field(alias="standingDetailScore")
    standing_detail_scoring: Optional[str] = Field(alias="standingDetailScoring")
    team_standing_order: Optional[int] = Field(alias="teamStandingOrder")
    team_standing_detail_order: Optional[int] = Field(alias="teamStandingDetailOrder")
    chunk_order: Optional[int] = Field(alias="chunkOrder")
    chunk_id: Optional[str] = Field(alias="chunkId")


class UnitInput(BaseModel):
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type: Optional[str] = Field(alias="unitType")
    unit_order: Optional[int] = Field(alias="unitOrder")
    is_startlist_published: Optional[bool] = Field(alias="isStartlistPublished")
    is_result_published: Optional[bool] = Field(alias="isResultPublished")
    is_phase_summary_published: Optional[bool] = Field(alias="isPhaseSummaryPublished")
    is_team_standing_published: Optional[bool] = Field(alias="isTeamStandingPublished")
    combined_discipline_order: Optional[str] = Field(alias="combinedDisciplineOrder")
    status: Optional[str]
    qualification_rule_code: Optional[str] = Field(alias="qualificationRuleCode")
    updated_on: Optional[str] = Field(alias="updatedOn")
    start_date: Optional[str] = Field(alias="startDate")
    start_time: Optional[str] = Field(alias="startTime")
    start_date_time: Optional[str] = Field(alias="startDateTime")
    wind: Optional[str]


AAapiQuery.update_forward_refs()
ChunkType.update_forward_refs()
ClientMetadataInput.update_forward_refs()
CompetitorInput.update_forward_refs()
CompetitorQueryInput.update_forward_refs()
EventInput.update_forward_refs()
FlashInterviewInput.update_forward_refs()
LiveCombinedSummaryDetailInput.update_forward_refs()
LivePhaseSummaryInput.update_forward_refs()
LivePhaseSummaryQuery.update_forward_refs()
LiveResultInput.update_forward_refs()
LiveResultTeamMemberInput.update_forward_refs()
MedalDetailInput.update_forward_refs()
MedalInput.update_forward_refs()
MedalMutationInput.update_forward_refs()
PhaseInput.update_forward_refs()
PhaseQueryInput.update_forward_refs()
PlacingTableDetailInput.update_forward_refs()
PlacingTableInput.update_forward_refs()
PreviousMedalQuery.update_forward_refs()
TeamQuery.update_forward_refs()
TeamScoringInput.update_forward_refs()
TeamStandingsInput.update_forward_refs()
UnitInput.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:50
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetLatestQualifiedCompetitors(BaseModel):
    get_latest_qualified_competitors: Optional[
        "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitors"
    ] = Field(alias="getLatestQualifiedCompetitors")


class GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitors(BaseModel):
    module_title: Optional[str] = Field(alias="moduleTitle")
    module_subtitle: Optional[str] = Field(alias="moduleSubtitle")
    competition_name: Optional[str] = Field(alias="competitionName")
    competition_year: Optional[int] = Field(alias="competitionYear")
    columns: Optional[
        List[
            Optional[
                "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsColumns"
            ]
        ]
    ]
    qualifications: Optional[
        List[
            Optional[
                "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualifications"
            ]
        ]
    ]


class GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsColumns(BaseModel):
    heading: Optional[str]
    align: Optional[str]
    field: Optional[str]


class GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualifications(
    BaseModel
):
    country_code: Optional[str] = Field(alias="countryCode")
    event_name: Optional[str] = Field(alias="eventName")
    mark: Optional[str]
    date: Optional[Any]
    competitor: Optional[
        "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitor"
    ]


class GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitor(
    BaseModel
):
    name: Optional[str]
    id: Optional[int]
    url_slug: Optional[str] = Field(alias="urlSlug")
    country_url_slug: Optional[str] = Field(alias="countryUrlSlug")
    birth_date: Optional[Any] = Field(alias="birthDate")
    team_members: Optional[
        List[
            Optional[
                "GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitorTeamMembers"
            ]
        ]
    ] = Field(alias="teamMembers")


class GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitorTeamMembers(
    BaseModel
):
    id: Optional[int]
    name: Optional[str]
    iaaf_id: Optional[int] = Field(alias="iaafId")
    url_slug: Optional[str] = Field(alias="urlSlug")


GetLatestQualifiedCompetitors.update_forward_refs()
GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitors.update_forward_refs()
GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsColumns.update_forward_refs()
GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualifications.update_forward_refs()
GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitor.update_forward_refs()
GetLatestQualifiedCompetitorsGetLatestQualifiedCompetitorsQualificationsCompetitorTeamMembers.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetRecordsDisciplines(BaseModel):
    get_records_disciplines: Optional[
        List[Optional["GetRecordsDisciplinesGetRecordsDisciplines"]]
    ] = Field(alias="getRecordsDisciplines")


class GetRecordsDisciplinesGetRecordsDisciplines(BaseModel):
    discipline_name: Optional[str] = Field(alias="disciplineName")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    type_name: Optional[str] = Field(alias="typeName")
    men: Optional[bool]
    women: Optional[bool]
    is_road: Optional[bool] = Field(alias="isRoad")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    order: Optional[int]
    type_order: Optional[int] = Field(alias="typeOrder")
    id: Optional[str]
    name: Optional[str]
    hash: Optional[str]
    type_code: Optional[str] = Field(alias="typeCode")
    name_url_slug: Optional[str] = Field(alias="nameUrlSlug")
    type_name_url_slug: Optional[str] = Field(alias="typeNameUrlSlug")
    updated_on: Optional[Any] = Field(alias="updatedOn")


GetRecordsDisciplines.update_forward_refs()
GetRecordsDisciplinesGetRecordsDisciplines.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetPhases(BaseModel):
    get_phases: Optional[List[Optional["GetPhasesGetPhases"]]] = Field(
        alias="getPhases"
    )


class GetPhasesGetPhases(BaseModel):
    id: Optional[int]
    phase_code: Optional[str] = Field(alias="phaseCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    discipline_order: Optional[int] = Field(alias="disciplineOrder")
    type_name: Optional[str] = Field(alias="typeName")
    type_code: Optional[str] = Field(alias="typeCode")
    type_order: Optional[int] = Field(alias="typeOrder")
    is_track: Optional[bool] = Field(alias="isTrack")
    is_field: Optional[bool] = Field(alias="isField")
    is_road: Optional[bool] = Field(alias="isRoad")
    is_combined: Optional[bool] = Field(alias="isCombined")
    is_walk: Optional[bool] = Field(alias="isWalk")
    is_indoor: Optional[bool] = Field(alias="isIndoor")
    is_reaction: Optional[bool] = Field(alias="isReaction")
    is_outdoor: Optional[bool] = Field(alias="isOutdoor")
    is_wind: Optional[bool] = Field(alias="isWind")
    is_relay: Optional[bool] = Field(alias="isRelay")
    is_valid_i_a_a_f: Optional[bool] = Field(alias="isValidIAAF")
    is_in_lane: Optional[bool] = Field(alias="isInLane")
    has_reaction_times: Optional[bool] = Field(alias="hasReactionTimes")
    has_wind_measurement: Optional[bool] = Field(alias="hasWindMeasurement")
    inout_code: Optional[bool] = Field(alias="inoutCode")
    has_team_standing: Optional[bool] = Field(alias="hasTeamStanding")
    disc_code_group: Optional[str] = Field(alias="discCodeGroup")
    phase_name: Optional[str] = Field(alias="phaseName")
    event_id: Optional[int] = Field(alias="eventId")
    phase_date_and_time: Optional[str] = Field(alias="phaseDateAndTime")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    is_startlist_published: Optional[bool] = Field(alias="isStartlistPublished")
    is_result_published: Optional[bool] = Field(alias="isResultPublished")
    is_phase_summary_published: Optional[bool] = Field(alias="isPhaseSummaryPublished")
    is_team_standing_published: Optional[bool] = Field(alias="isTeamStandingPublished")
    combined_discipline_order: Optional[str] = Field(alias="combinedDisciplineOrder")
    phase_order: Optional[int] = Field(alias="phaseOrder")
    phase_session_order: Optional[int] = Field(alias="phaseSessionOrder")
    phase_session_name: Optional[str] = Field(alias="phaseSessionName")
    primary_phase_order: Optional[int] = Field(alias="primaryPhaseOrder")
    status: Optional[int]
    has_time: Optional[int] = Field(alias="hasTime")
    updated_on: Optional[str] = Field(alias="updatedOn")
    units: Optional[List[Optional["GetPhasesGetPhasesUnits"]]]
    event_store_id: Optional[str] = Field(alias="eventStoreId")


class GetPhasesGetPhasesUnits(BaseModel):
    id: Optional[int]
    phase_id: Optional[int] = Field(alias="phaseId")
    unit_name: Optional[str] = Field(alias="unitName")
    unit_type: Optional[str] = Field(alias="unitType")
    unit_order: Optional[int] = Field(alias="unitOrder")
    is_startlist_published: Optional[bool] = Field(alias="isStartlistPublished")
    is_result_published: Optional[bool] = Field(alias="isResultPublished")
    is_phase_summary_published: Optional[bool] = Field(alias="isPhaseSummaryPublished")
    is_team_standing_published: Optional[bool] = Field(alias="isTeamStandingPublished")
    combined_discipline_order: Optional[str] = Field(alias="combinedDisciplineOrder")
    status: Optional[str]
    qualification_rule_code: Optional[str] = Field(alias="qualificationRuleCode")
    updated_on: Optional[str] = Field(alias="updatedOn")
    start_date: Optional[str] = Field(alias="startDate")
    start_time: Optional[str] = Field(alias="startTime")
    start_date_time: Optional[str] = Field(alias="startDateTime")
    wind: Optional[str]


GetPhases.update_forward_refs()
GetPhasesGetPhases.update_forward_refs()
GetPhasesGetPhasesUnits.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetVerification(BaseModel):
    get_verification: Optional[
        List[Optional["GetVerificationGetVerification"]]
    ] = Field(alias="getVerification")


class GetVerificationGetVerification(BaseModel):
    confirmation_code: Optional[str] = Field(alias="confirmationCode")
    username: Optional[str]


GetVerification.update_forward_refs()
GetVerificationGetVerification.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetAthleteRepresentativeTopList(BaseModel):
    get_athlete_representative_top_list: Optional[
        "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopList"
    ] = Field(alias="getAthleteRepresentativeTopList")


class GetAthleteRepresentativeTopListGetAthleteRepresentativeTopList(BaseModel):
    genders: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListGenders"
            ]
        ]
    ]
    events: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEvents"
            ]
        ]
    ]
    toplist: Optional[
        "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplist"
    ]
    event_types: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEventTypes"
            ]
        ]
    ] = Field(alias="eventTypes")


class GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListGenders(BaseModel):
    gender: Optional[str]
    gender_code: Optional[str] = Field(alias="genderCode")
    selected_gender: Optional[bool] = Field(alias="selectedGender")


class GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEvents(BaseModel):
    event: Optional[str]
    event_id: Optional[int] = Field(alias="eventId")
    gender_code: Optional[str] = Field(alias="genderCode")
    event_type_id: Optional[int] = Field(alias="eventTypeId")
    selected_event: Optional[bool] = Field(alias="selectedEvent")


class GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplist(BaseModel):
    event: Optional[str]
    toplist_date: Optional[str] = Field(alias="toplistDate")
    athletes: Optional[
        List[
            Optional[
                "GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplistAthletes"
            ]
        ]
    ]


class GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplistAthletes(
    BaseModel
):
    rank: Optional[int]
    result: Optional[str]
    country: Optional[str]
    last_name: Optional[str] = Field(alias="lastName")
    athlete_id: Optional[int] = Field(alias="athleteId")
    birthdate: Optional[str]
    first_name: Optional[str] = Field(alias="firstName")
    result_date: Optional[str] = Field(alias="resultDate")
    athlete_name: Optional[str] = Field(alias="athleteName")
    country_code: Optional[str] = Field(alias="countryCode")
    result_venue: Optional[str] = Field(alias="resultVenue")
    representative_name: Optional[str] = Field(alias="representativeName")
    representative_type_id: Optional[int] = Field(alias="representativeTypeId")
    representative_last_name: Optional[str] = Field(alias="representativeLastName")
    athlete_representative_id: Optional[int] = Field(alias="athleteRepresentativeId")
    representative_first_name: Optional[str] = Field(alias="representativeFirstName")


class GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEventTypes(
    BaseModel
):
    event_type: Optional[str] = Field(alias="eventType")
    event_type_id: Optional[int] = Field(alias="eventTypeId")
    selected_event_type: Optional[bool] = Field(alias="selectedEventType")


GetAthleteRepresentativeTopList.update_forward_refs()
GetAthleteRepresentativeTopListGetAthleteRepresentativeTopList.update_forward_refs()
GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListGenders.update_forward_refs()
GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEvents.update_forward_refs()
GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplist.update_forward_refs()
GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListToplistAthletes.update_forward_refs()
GetAthleteRepresentativeTopListGetAthleteRepresentativeTopListEventTypes.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class AirQualityDeviceElementReads(BaseModel):
    air_quality_device_element_reads: Optional[
        List[Optional["AirQualityDeviceElementReadsAirQualityDeviceElementReads"]]
    ] = Field(alias="airQualityDeviceElementReads")


class AirQualityDeviceElementReadsAirQualityDeviceElementReads(BaseModel):
    value: Optional[str]
    validation: Optional[str]
    reason: Optional[str]
    ts: Optional[Any]


AirQualityDeviceElementReads.update_forward_refs()
AirQualityDeviceElementReadsAirQualityDeviceElementReads.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetCompetitor(BaseModel):
    get_competitor: Optional["GetCompetitorGetCompetitor"] = Field(
        alias="getCompetitor"
    )


class GetCompetitorGetCompetitor(BaseModel):
    competitor_id: Optional[int] = Field(alias="competitorId")
    old_competitor_id: Optional[int] = Field(alias="oldCompetitorId")
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    birth_date: Optional[str] = Field(alias="birthDate")
    birth_place: Optional[str] = Field(alias="birthPlace")
    birth_country_code: Optional[str] = Field(alias="birthCountryCode")
    birth_place_country_name: Optional[str] = Field(alias="birthPlaceCountryName")
    team_name: Optional[str] = Field(alias="teamName")
    country_name: Optional[str] = Field(alias="countryName")
    country_code: Optional[str] = Field(alias="countryCode")
    sex_code: Optional[str] = Field(alias="sexCode")
    sex_name: Optional[str] = Field(alias="sexName")
    full_bio: Optional[str] = Field(alias="fullBio")
    butlers_bio: Optional[str] = Field(alias="butlersBio")
    event_store_id: Optional[str] = Field(alias="eventStoreId")


GetCompetitor.update_forward_refs()
GetCompetitorGetCompetitor.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class GetNewsTicker(BaseModel):
    get_news_ticker: Optional["GetNewsTickerGetNewsTicker"] = Field(
        alias="getNewsTicker"
    )


class GetNewsTickerGetNewsTicker(BaseModel):
    content: Optional[str]


GetNewsTicker.update_forward_refs()
GetNewsTickerGetNewsTicker.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetBanners(BaseModel):
    get_banners: Optional["GetBannersGetBanners"] = Field(alias="getBanners")


class GetBannersGetBanners(BaseModel):
    id: Optional[str]
    title: Optional[str]
    banner_items: Optional[List[Optional["GetBannersGetBannersBannerItems"]]] = Field(
        alias="bannerItems"
    )


class GetBannersGetBannersBannerItems(BaseModel):
    id: Optional[str]
    url: Optional[str]
    primary_media_id: Optional[List[Optional[str]]] = Field(alias="primaryMediaId")
    primary_media: Optional[
        List[Optional["GetBannersGetBannersBannerItemsPrimaryMedia"]]
    ] = Field(alias="primaryMedia")
    order: Optional[int]


class GetBannersGetBannersBannerItemsPrimaryMedia(BaseModel):
    id: Optional[str]
    title: Optional[str]
    s_e_o_title: Optional[str] = Field(alias="sEOTitle")
    url_slug: Optional[str] = Field(alias="urlSlug")
    credit: Optional[str]
    show_in_media: Optional[bool] = Field(alias="showInMedia")
    complete: Optional[bool]
    file_name: Optional[str] = Field(alias="fileName")
    remote_item_code: Optional[str] = Field(alias="remoteItemCode")
    x_m_l_file_name360: Optional[str] = Field(alias="xMLFileName360")
    file_name_url: Optional[str] = Field(alias="fileNameUrl")
    type: Optional[int]
    format: Optional[int]
    hosting: Optional[int]
    related_links: Optional[List[Optional[str]]] = Field(alias="relatedLinks")
    source_width: Optional[int] = Field(alias="sourceWidth")
    source_height: Optional[int] = Field(alias="sourceHeight")
    available_ratios: Optional[List[Optional[int]]] = Field(alias="availableRatios")
    related_sex_codes: Optional[List[Optional[int]]] = Field(alias="relatedSexCodes")
    related_age_groups: Optional[List[Optional[int]]] = Field(alias="relatedAgeGroups")
    related_event_phases: Optional[List[Optional[int]]] = Field(
        alias="relatedEventPhases"
    )
    status: Optional[int]
    live_from: Optional[Any] = Field(alias="liveFrom")
    created_on: Optional[str] = Field(alias="createdOn")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    created_by_id: Optional[str] = Field(alias="createdById")
    updated_by_id: Optional[str] = Field(alias="updatedById")


GetBanners.update_forward_refs()
GetBannersGetBanners.update_forward_refs()
GetBannersGetBannersBannerItems.update_forward_refs()
GetBannersGetBannersBannerItemsPrimaryMedia.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetUser(BaseModel):
    get_user: Optional["GetUserGetUser"] = Field(alias="getUser")


class GetUserGetUser(BaseModel):
    cognito_id: str = Field(alias="cognitoId")
    registration_date: Optional[str] = Field(alias="registrationDate")
    date_modified: Optional[str] = Field(alias="dateModified")
    name: Optional[str]
    settings: Optional["GetUserGetUserSettings"]


class GetUserGetUserSettings(BaseModel):
    first_name: Optional[str] = Field(alias="firstName")
    last_name: Optional[str] = Field(alias="lastName")
    email: Optional[str]
    age_group: Optional[str] = Field(alias="ageGroup")
    sex: Optional[str]
    country_code: Optional[str] = Field(alias="countryCode")
    national_team_support_country_code: Optional[str] = Field(
        alias="nationalTeamSupportCountryCode"
    )
    mailing_list_consent: Optional[bool] = Field(alias="mailingListConsent")
    kids_athletics_terms_and_conditions: Optional[str] = Field(
        alias="kidsAthleticsTermsAndConditions"
    )
    user_types: Optional[List[Optional[str]]] = Field(alias="userTypes")
    user_sub_types: Optional[List[Optional[str]]] = Field(alias="userSubTypes")
    discipline_categories: Optional[List[Optional[str]]] = Field(
        alias="disciplineCategories"
    )
    interests: Optional[List[Optional[str]]]
    contact_preferences: Optional[List[Optional[str]]] = Field(
        alias="contactPreferences"
    )
    source: Optional[str]
    tags: Optional[List[Optional[str]]]
    followed_competitors: Optional[List[Optional[int]]] = Field(
        alias="followedCompetitors"
    )


GetUser.update_forward_refs()
GetUserGetUser.update_forward_refs()
GetUserGetUserSettings.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class HeadToHead(BaseModel):
    head_to_head: Optional["HeadToHeadHeadToHead"] = Field(alias="headToHead")


class HeadToHeadHeadToHead(BaseModel):
    disciplines: Optional[List[Optional["HeadToHeadHeadToHeadDisciplines"]]]
    opponents: Optional[List[Optional["HeadToHeadHeadToHeadOpponents"]]]
    parameters: Optional["HeadToHeadHeadToHeadParameters"]
    results: Optional["HeadToHeadHeadToHeadResults"]


class HeadToHeadHeadToHeadDisciplines(BaseModel):
    id: Optional[str]
    name: Optional[str]


class HeadToHeadHeadToHeadOpponents(BaseModel):
    birth_date: Optional[str] = Field(alias="birthDate")
    country: Optional[str]
    family_name: Optional[str] = Field(alias="familyName")
    gender: Optional[str]
    given_name: Optional[str] = Field(alias="givenName")
    id: Optional[int]


class HeadToHeadHeadToHeadParameters(BaseModel):
    head_to_head_discipline: Optional[str] = Field(alias="headToHeadDiscipline")
    head_to_head_end_date: Optional[str] = Field(alias="headToHeadEndDate")
    head_to_head_final_only: Optional[bool] = Field(alias="headToHeadFinalOnly")
    head_to_head_opponent: Optional[int] = Field(alias="headToHeadOpponent")
    head_to_head_start_date: Optional[str] = Field(alias="headToHeadStartDate")


class HeadToHeadHeadToHeadResults(BaseModel):
    athlete1_wins: Optional[int] = Field(alias="athlete1Wins")
    athlete2_wins: Optional[int] = Field(alias="athlete2Wins")
    results: Optional[List[Optional["HeadToHeadHeadToHeadResultsResults"]]]


class HeadToHeadHeadToHeadResultsResults(BaseModel):
    athlete1_wins: Optional[bool] = Field(alias="athlete1Wins")
    athlete2_wins: Optional[bool] = Field(alias="athlete2Wins")
    competition: Optional[str]
    date: Optional[str]
    discipline: Optional[str]
    place1: Optional[str]
    place2: Optional[str]
    race: Optional[str]
    race_type: Optional[str] = Field(alias="raceType")
    result1: Optional[str]
    result2: Optional[str]


HeadToHead.update_forward_refs()
HeadToHeadHeadToHead.update_forward_refs()
HeadToHeadHeadToHeadDisciplines.update_forward_refs()
HeadToHeadHeadToHeadOpponents.update_forward_refs()
HeadToHeadHeadToHeadParameters.update_forward_refs()
HeadToHeadHeadToHeadResults.update_forward_refs()
HeadToHeadHeadToHeadResultsResults.update_forward_refs()



# Generated by ariadne-codegen on 2023-06-06 10:49
# Source: graphql/queries.graphql

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetPlacingTableDetails(BaseModel):
    get_placing_table_details: Optional[
        List[Optional["GetPlacingTableDetailsGetPlacingTableDetails"]]
    ] = Field(alias="getPlacingTableDetails")


class GetPlacingTableDetailsGetPlacingTableDetails(BaseModel):
    id: int
    placing_table_id: int = Field(alias="placingTableId")
    competitor_id: Optional[int] = Field(alias="competitorId")
    discipline_code: Optional[str] = Field(alias="disciplineCode")
    discipline_name: Optional[str] = Field(alias="disciplineName")
    competitor_first_name: Optional[str] = Field(alias="competitorFirstName")
    competitor_last_name: Optional[str] = Field(alias="competitorLastName")
    sex_code: Optional[str] = Field(alias="sexCode")
    placing_date: Optional[Any] = Field(alias="placingDate")
    details_order: Optional[int] = Field(alias="detailsOrder")
    event_id: Optional[int] = Field(alias="eventId")
    type_id: Optional[int] = Field(alias="typeId")
    type_name: Optional[str] = Field(alias="typeName")
    type_abbreviation: Optional[str] = Field(alias="typeAbbreviation")
    result_mark: Optional[str] = Field(alias="resultMark")
    placing_points: Optional[str] = Field(alias="placingPoints")
    result_id: Optional[int] = Field(alias="resultId")
    phase_id: Optional[int] = Field(alias="phaseId")
    country_code: Optional[str] = Field(alias="countryCode")
    updated_on: Optional[Any] = Field(alias="updatedOn")
    event_store_id: Optional[str] = Field(alias="eventStoreId")


GetPlacingTableDetails.update_forward_refs()
GetPlacingTableDetailsGetPlacingTableDetails.update_forward_refs()
